import { ARIAGlobalStatesAndProperties } from "../patterns/aria-global";
import { StartEnd } from "../patterns/start-end";
import { SelectPosition, SelectRole } from "./select.options";
import { FormAssociatedSelect } from "./select.form-associated";
/**
 * A Select Custom HTML Element.
 * Implements the {@link https://www.w3.org/TR/wai-aria-1.1/#select | ARIA select }.
 *
 * @public
 */
export declare class Select extends FormAssociatedSelect {
    /**
     * The open attribute.
     *
     * @internal
     */
    open: boolean;
    protected openChanged(): void;
    /**
     *  Reflects the placement for the listbox when the select is open.
     *
     * @public
     */
    positionAttribute: SelectPosition;
    /**
     * Indicates the initial state of the position attribute.
     *
     * @internal
     */
    private forcedPosition;
    /**
     * The role of the element.
     *
     * @public
     * @remarks
     * HTML Attribute: role
     */
    role: SelectRole;
    /**
     * Holds the current state for the calculated position of the listbox.
     *
     * @public
     */
    position: SelectPosition;
    /**
     * Calculate and apply listbox positioning based on available viewport space.
     *
     * @param force - direction to force the listbox to display
     * @public
     */
    setPositioning(): void;
    /**
     * The max height for the listbox when opened.
     *
     * @internal
     */
    maxHeight: number;
    /**
     * The value displayed on the button.
     *
     * @public
     */
    get displayValue(): string;
    /**
     * Sets the value when the options are changed.
     *
     * @param prev - The previous value
     * @param next - the new value
     * @internal
     */
    selectedOptionsChanged(prev: any, next: any): void;
    /**
     * @internal
     */
    clickHandler(e: MouseEvent): boolean | void;
    focusoutHandler(e: FocusEvent): boolean | void;
    optionsChanged(prev: any, next: any): void;
    /**
     * Reset and fill the proxy to match the component's options
     * @internal
     */
    private setProxyOptions;
    keydownHandler(e: KeyboardEvent): boolean | void;
    connectedCallback(): void;
    constructor();
}
/**
 * Includes ARIA states and properties relating to the ARIA select role.
 *
 * @public
 */
export declare class DelegatesARIASelect extends ARIAGlobalStatesAndProperties {
    /**
     * See {@link https://www.w3.org/WAI/PF/aria/roles#button} for more information
     * @public
     * @remarks
     * HTML Attribute: aria-expanded
     */
    ariaExpanded: "true" | "false" | undefined;
}
/**
 * @internal
 */
export interface Select extends StartEnd, DelegatesARIASelect {
}
